@@ -1,6 +1,6 @@
 package HTML::JQuery;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 NAME
 
@@ -464,14 +464,44 @@ sub keystrokes {
     return $key if $ret;        
 }
 
-sub get {
-    my ($self, $uri, $element) = @_;
+=head2 get
 
+Sends a GET request to a page via AJAX and adds the data to 
+the specified element.
+
+    $j->onClick({
+        class => 'button',
+        event => $j->get('ajax/search', { search => 'content' })
+    });
+
+=cut
+
+sub get {
+    my ($self, $uri, $args) = @_;
+
+    my ($id, $class, $element, $attr, $val);
+
+    $attr = "";
+    for (keys %$args) {
+        $id = $args->{$_} if ($_ eq 'id');
+        $class = $args->{$_} if ($_ eq 'class');
+        $element = $args->{$_} if ($_ eq 'selector');
+    }
+
+    if ($id) { delete $args->{id}; $element = "\$('#$id')"; }
+    elsif ($class) { delete $args->{class}; $element = "\$('.$class')"; }
+
+    for (keys %$args) {
+        $attr .= "'$_' : '$args->{$_}', ";
+    }
+
+    $attr = eval $attr;
     my $get = qq{
         \$.get(
             "$uri",
+            \{ $attr \},
             function(data) \{
-                \$('$element').html(data);
+                $element.html(data);
             \}
         );
     };
